==> chromium-browser_25.0.1364.160.orig.tar.xz: chromium-browser-25.0.1364.160/src/content/renderer/browser_plugin/browser_plugin_manager.cc <==
// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "content/renderer/browser_plugin/browser_plugin_manager.h"

#include "base/lazy_instance.h"
#include "base/threading/thread_local.h"
#include "content/public/renderer/render_thread.h"
#include "content/renderer/browser_plugin/browser_plugin.h"
#include "content/renderer/browser_plugin/browser_plugin_manager_factory.h"
#include "content/renderer/browser_plugin/browser_plugin_manager_impl.h"

namespace content {

// static
BrowserPluginManagerFactory* BrowserPluginManager::factory_ = NULL;

BrowserPluginManager* BrowserPluginManager::Create(
    RenderViewImpl* render_view) {
  if (factory_)
    return factory_->CreateBrowserPluginManager(render_view);
  return new BrowserPluginManagerImpl(render_view);
}

BrowserPluginManager::BrowserPluginManager(RenderViewImpl* render_view)
    : RenderViewObserver(render_view),
      render_view_(render_view->AsWeakPtr()),
      browser_plugin_counter_(0) {
}

BrowserPluginManager::~BrowserPluginManager() {
}

void BrowserPluginManager::AddBrowserPlugin(
    int instance_id,
    BrowserPlugin* browser_plugin) {
  instances_.AddWithID(browser_plugin, instance_id);
}

void BrowserPluginManager::RemoveBrowserPlugin(int instance_id) {
  instances_.Remove(instance_id);
}

BrowserPlugin* BrowserPluginManager::GetBrowserPlugin(int instance_id) const {
  return instances_.Lookup(instance_id);
}

void BrowserPluginManager::SetEmbedderFocus(const RenderViewImpl* embedder,
                                            bool focused) {
  IDMap<BrowserPlugin>::iterator iter(&instances_);
  while (!iter.IsAtEnd()) {
    BrowserPlugin* browser_plugin = iter.GetCurrentValue();
    if (browser_plugin->render_view() == embedder)
      browser_plugin->SetEmbedderFocus(focused);
    iter.Advance();
  }
}

}  // namespace content

==> chromium-browser_28.0.1500.95.orig.tar.xz: chromium-browser-28.0.1500.95/src/content/renderer/browser_plugin/browser_plugin_manager.cc <==
// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "content/renderer/browser_plugin/browser_plugin_manager.h"

#include "base/lazy_instance.h"
#include "base/threading/thread_local.h"
#include "content/public/renderer/render_thread.h"
#include "content/renderer/browser_plugin/browser_plugin.h"
#include "content/renderer/browser_plugin/browser_plugin_manager_factory.h"
#include "content/renderer/browser_plugin/browser_plugin_manager_impl.h"

namespace content {

// static
BrowserPluginManagerFactory* BrowserPluginManager::factory_ = NULL;

BrowserPluginManager* BrowserPluginManager::Create(
    RenderViewImpl* render_view) {
  if (factory_)
    return factory_->CreateBrowserPluginManager(render_view);
  return new BrowserPluginManagerImpl(render_view);
}

BrowserPluginManager::BrowserPluginManager(RenderViewImpl* render_view)
    : RenderViewObserver(render_view),
      render_view_(render_view->AsWeakPtr()) {
}

BrowserPluginManager::~BrowserPluginManager() {
}

void BrowserPluginManager::AddBrowserPlugin(
    int instance_id,
    BrowserPlugin* browser_plugin) {
  instances_.AddWithID(browser_plugin, instance_id);
}

void BrowserPluginManager::RemoveBrowserPlugin(int instance_id) {
  instances_.Remove(instance_id);
}

BrowserPlugin* BrowserPluginManager::GetBrowserPlugin(int instance_id) const {
  return instances_.Lookup(instance_id);
}

void BrowserPluginManager::UpdateDeviceScaleFactor(float device_scale_factor) {
  IDMap<BrowserPlugin>::iterator iter(&instances_);
  while (!iter.IsAtEnd()) {
    iter.GetCurrentValue()->UpdateDeviceScaleFactor(device_scale_factor);
    iter.Advance();
  }
}

void BrowserPluginManager::UpdateFocusState() {
  IDMap<BrowserPlugin>::iterator iter(&instances_);
  while (!iter.IsAtEnd()) {
    iter.GetCurrentValue()->UpdateGuestFocusState();
    iter.Advance();
  }
}

}  // namespace content
